qca-nss-drv: Fix IPv4 node statistics update for multicast rules

Change-Id: I88f0f476fa85ea22bbb1f732c35bdea22332877d
Signed-off-by: Kiran Kumar C.S.K <kkumarcs@codeaurora.org>
diff --git a/nss_ipv6.c b/nss_ipv6.c
index d46e4f7..16067a4 100644
--- a/nss_ipv6.c
+++ b/nss_ipv6.c
@@ -82,6 +82,12 @@
 	nss_top->stats_ipv6[NSS_STATS_IPV6_CONNECTION_EVICTIONS] += nins->ipv6_connection_evictions;
 	nss_top->stats_ipv6[NSS_STATS_IPV6_FRAGMENTATIONS] += nins->ipv6_fragmentations;
 	nss_top->stats_ipv6[NSS_STATS_IPV6_FRAG_FAILS] += nins->ipv6_frag_fails;
+	nss_top->stats_ipv6[NSS_STATS_IPV6_MC_CONNECTION_CREATE_REQUESTS] += nins->ipv6_mc_connection_create_requests;
+	nss_top->stats_ipv6[NSS_STATS_IPV6_MC_CONNECTION_UPDATE_REQUESTS] += nins->ipv6_mc_connection_update_requests;
+	nss_top->stats_ipv6[NSS_STATS_IPV6_MC_CONNECTION_CREATE_INVALID_INTERFACE] += nins->ipv6_mc_connection_create_invalid_interface;
+	nss_top->stats_ipv6[NSS_STATS_IPV6_MC_CONNECTION_DESTROY_REQUESTS] += nins->ipv6_mc_connection_destroy_requests;
+	nss_top->stats_ipv6[NSS_STATS_IPV6_MC_CONNECTION_DESTROY_MISSES] += nins->ipv6_mc_connection_destroy_misses;
+	nss_top->stats_ipv6[NSS_STATS_IPV6_MC_CONNECTION_FLUSHES] += nins->ipv6_mc_connection_flushes;
 
 	for (i = 0; i < NSS_EXCEPTION_EVENT_IPV6_MAX; i++) {
 		 nss_top->stats_if_exception_ipv6[i] += nins->exception_events[i];
@@ -285,7 +291,7 @@
 {
 	if (nim->cm.response != NSS_CMN_RESPONSE_ACK) {
 		/*
 		 * Error, hence we are not updating the nss_ipv4_conn_cfg
 		 * Restore the current_value to its previous state
 		 */
 		i6cfgp.response = NSS_FAILURE;
@@ -294,7 +300,7 @@
 	}
 
 	/*
 	 * Sucess at NSS FW, hence updating nss_ipv4_conn_cfg, with the valid value
 	 * saved at the sysctl handler.
 	 */
 	nss_info("IPv6 connection configuration success: %d\n", nim->cm.error);
@@ -382,7 +388,7 @@
 
 	/*
 	 * ACK/NACK received from NSS FW
 	 * If ACK: Callback function will update nss_ipv4_conn_cfg with
 	 * i6cfgp.num_conn_valid, which holds the user input
 	 */
 	if (NSS_FAILURE == i6cfgp.response) {
@@ -443,7 +449,7 @@
 
 /*
  * nss_ipv6_register_sysctl()
  *	Register sysctl specific to ipv4
  */
 void nss_ipv6_register_sysctl(void)
 {
@@ -458,7 +464,7 @@
 
 /*
  * nss_ipv6_unregister_sysctl()
  *	Unregister sysctl specific to ipv4
  */
 void nss_ipv6_unregister_sysctl(void)
 {
@@ -285,7 +291,7 @@
 	if (nim->cm.response != NSS_CMN_RESPONSE_ACK) {
 		/*
-		 * Error, hence we are not updating the nss_ipv4_conn_cfg
+		 * Error, hence we are not updating the nss_ipv6_conn_cfg
 		 * Restore the current_value to its previous state
 		 */
@@ -294,7 +300,7 @@
 
 	/*
-	 * Sucess at NSS FW, hence updating nss_ipv4_conn_cfg, with the valid value
+	 * Sucess at NSS FW, hence updating nss_ipv6_conn_cfg, with the valid value
 	 * saved at the sysctl handler.
 	 */
@@ -382,7 +388,7 @@
 	/*
 	 * ACK/NACK received from NSS FW
-	 * If ACK: Callback function will update nss_ipv4_conn_cfg with
+	 * If ACK: Callback function will update nss_ipv6_conn_cfg with
 	 * i6cfgp.num_conn_valid, which holds the user input
 	 */
@@ -443,7 +449,7 @@
 /*
  * nss_ipv6_register_sysctl()
- *	Register sysctl specific to ipv4
+ *	Register sysctl specific to ipv6
  */
 void nss_ipv6_register_sysctl(void)
@@ -458,7 +464,7 @@
 /*
  * nss_ipv6_unregister_sysctl()
- *	Unregister sysctl specific to ipv4
+ *	Unregister sysctl specific to ipv6
  */
 void nss_ipv6_unregister_sysctl(void)